diff --git a/wp-includes/general-template.php b/wp-includes/general-template.php
index 11d4b77..0098cbd 100644
--- a/wp-includes/general-template.php
+++ b/wp-includes/general-template.php
@@ -1495,24 +1495,25 @@ function the_archive_title( $before = '', $after = '' ) {
  */
 function get_the_archive_title() {
 	if ( is_category() ) {
-		/* translators: Category archive title. %s: Category name */
-		$title = sprintf( __( 'Category: %s' ), single_cat_title( '', false ) );
+       $title = single_cat_title( '', false );
+       $prefix = __( 'Category: ' );
 	} elseif ( is_tag() ) {
-		/* translators: Tag archive title. %s: Tag name */
-		$title = sprintf( __( 'Tag: %s' ), single_tag_title( '', false ) );
+       $title = single_tag_title( '', false );
+       $prefix = __( 'Tag: ' );
 	} elseif ( is_author() ) {
-		/* translators: Author archive title. %s: Author name */
-		$title = sprintf( __( 'Author: %s' ), '<span class="vcard">' . get_the_author() . '</span>' );
+       $title = '<span class="vcard">' . get_the_author() . '</span>';
+       $prefix = __( 'Author: ' );
 	} elseif ( is_year() ) {
-		/* translators: Yearly archive title. %s: Year */
-		$title = sprintf( __( 'Year: %s' ), get_the_date( _x( 'Y', 'yearly archives date format' ) ) );
+       $title = get_the_date( _x( 'Y', 'yearly archives date format' ) );
+       $prefix = __( 'Year: ' );
 	} elseif ( is_month() ) {
-		/* translators: Monthly archive title. %s: Month name and year */
-		$title = sprintf( __( 'Month: %s' ), get_the_date( _x( 'F Y', 'monthly archives date format' ) ) );
+       $title = get_the_date( _x( 'F Y', 'monthly archives date format' ) );
+       $prefix = __( 'Month: ' );
 	} elseif ( is_day() ) {
-		/* translators: Daily archive title. %s: Date */
-		$title = sprintf( __( 'Day: %s' ), get_the_date( _x( 'F j, Y', 'daily archives date format' ) ) );
+       $title = get_the_date( _x( 'F j, Y', 'daily archives date format' ) );
+       $prefix = __( 'Day: ' );
 	} elseif ( is_tax( 'post_format' ) ) {
+		$prefix = '';
 		if ( is_tax( 'post_format', 'post-format-aside' ) ) {
 			$title = _x( 'Asides', 'post format archive title' );
 		} elseif ( is_tax( 'post_format', 'post-format-gallery' ) ) {
@@ -1533,18 +1534,28 @@ function get_the_archive_title() {
 			$title = _x( 'Chats', 'post format archive title' );
 		}
 	} elseif ( is_post_type_archive() ) {
-		/* translators: Post type archive title. %s: Post type name */
-		$title = sprintf( __( 'Archives: %s' ), post_type_archive_title( '', false ) );
+       $title = post_type_archive_title( '', false );
+       $prefix = __( 'Archives: ' );
 	} elseif ( is_tax() ) {
+		$title = single_term_title( '', false );
 		$tax = get_taxonomy( get_queried_object()->taxonomy );
-		/* translators: Taxonomy term archive title. 1: Taxonomy singular name, 2: Current taxonomy term */
-		$title = sprintf( __( '%1$s: %2$s' ), $tax->labels->singular_name, single_term_title( '', false ) );
+		/* translators: 1: Taxonomy singular name */
+		$prefix = sprintf( _x( '%1$s: ', 'Taxonomy singular name' ), $tax->labels->singular_name );
 	} else {
-		$title = __( 'Archives' );
+		$title = '';
+		$prefix = __( 'Archives' );
 	}
-
 	/**
-	 * Filters the archive title.
+	 * Filters the archive title prefix.
+	 *
+	 * @since 5.2
+	 *
+	 * @param string $prefix Archive title prefix.
+	 */
+	$prefix = apply_filters( 'get_the_archive_title_prefix', $prefix );
+	$title = $prefix . $title;
+	/**
+	 * Filters the archive title (with the archive title prefix).
 	 *
 	 * @since 4.1.0
 	 *
